#!/usr/bin/env python
#coding:utf-8
"""
  Author:   --<v1ll4n>
  Purpose: Test for decologger
  Created: 2016/12/18
"""

import unittest
import traceback
from .decologger import Decologger




if __name__ == '__main__':
    unittest.main()


#!/usr/bin/env python
#coding:utf-8
"""
  Author:   --<v1ll4n>
  Purpose: Test for utils
  Created: 2017/1/2
"""

import unittest
try:
    from queue import Queue
except:
    from Queue import Queue
from . import ip_calc_utils
from .ip_calc_utils import *
from .print_utils import print_bar
from .inspect_utils import *
from .import_utils import import_by_path
from . import queue_utils



        
    
    
    
if __name__ == '__main__':
    unittest.main()